# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/harmony/agreement.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x65olymp/harmony/agreement.proto\x12\x0e\x65olymp.harmony\"O\n\tAgreement\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08required\x18\x02 \x01(\x08\x12\x0f\n\x07summary\x18\n \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x0b \x01(\tB1Z/github.com/eolymp/go-sdk/eolymp/harmony;harmonyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.harmony.agreement_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/eolymp/go-sdk/eolymp/harmony;harmony'
  _AGREEMENT._serialized_start=50
  _AGREEMENT._serialized_end=129
# @@protoc_insertion_point(module_scope)
